/*
 * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS HEADER.
 *
 * The contents of this file are subject to the terms of either the GNU
 * General Public License Version 2 only ("GPL") or the Common
 * Development and Distribution License("CDDL") (collectively, the
 * "License"). You may not use this file except in compliance with the
 * License. You can obtain a copy of the License at
 * http://www.netbeans.org/cddl-gplv2.html
 * or nbbuild/licenses/CDDL-GPL-2-CP. See the License for the
 * specific language governing permissions and limitations under the
 * License.  When distributing the software, include this License Header
 * Notice in each file and include the License file at
 * nbbuild/licenses/CDDL-GPL-2-CP.  Sun designates this
 * particular file as subject to the "Classpath" exception as provided
 * by Sun in the GPL Version 2 section of the License file that
 * accompanied this code. If applicable, add the following below the
 * License Header, with the fields enclosed by brackets [] replaced by
 * your own identifying information:
 * "Portions Copyrighted [year] [name of copyright owner]"
 *
 * Contributor(s):
 *
 * Portions Copyrighted 2009 Jaroslav Tulach
 */

package cz.xelfi.quoridor.webidor;

import cz.xelfi.quoridor.webidor.resources.Games;
import cz.xelfi.quoridor.webidor.resources.Quoridor;
import java.io.File;
import java.io.FileOutputStream;
import java.io.IOException;
import org.junit.After;
import org.junit.Before;
import org.junit.Test;
import static org.junit.Assert.*;

/**
 *
 * @author Jaroslav Tulach <jtulach@netbeans.org>
 */
public class GamesTest extends Object {
    private File dir;

    @Before
    public void setUp() throws Exception {
        dir = File.createTempFile("quoridor", ".dir");
        dir.delete();
        System.setProperty("quoridor.dir", dir.getPath());
    }

    @After
    public void tearDown() throws Exception {
        deleteRec(dir);
    }

    static void deleteRec(File dir) throws IOException {
        if (dir == null) {
            return;
        }
        File[] arr = dir.listFiles();
        if (arr != null) {
            for (File f : arr) {
                deleteRec(f);
            }
        }
        dir.delete();
    }

    @Test public void testCreateAGame() throws Exception {
        File f = new File(dir, "x");
        f.getParentFile().mkdirs();
        FileOutputStream os = new FileOutputStream(f);
        os.write("# white: W\n# black: B\n# status: IN_PROGRESS\nN S\n\n".getBytes("UTF-8"));
        os.close();

        Thread.sleep(1000);
        
        long middle = f.lastModified();

        Thread.sleep(1000);

        Games games = new Games(dir, new Quoridor());
        Game g = games.getBoardInfo("x", -1);
        assertNotNull("Game found", g);
        assertNotNull("Board found", g.getBoard());
        assertEquals("List of moves has two", 2, g.getMoves().size());

        assertEquals("Last move is last touch of the file", middle, g.getId().getModified());
    }

    @Test public void testLoadGameWithComments() throws Exception {
        File f = new File(dir, "x");
        f.getParentFile().mkdirs();
        FileOutputStream os = new FileOutputStream(f);
        os.write("# white: W\n# black: B\n# status: IN_PROGRESS\nN #good move\n... S # ok move\n\n".getBytes("UTF-8"));
        os.close();

        Thread.sleep(1000);

        long middle = f.lastModified();

        Thread.sleep(1000);

        Games games = new Games(dir, new Quoridor());
        Game g = games.getBoardInfo("x", -1);
        assertNotNull("Game found", g);
        assertNotNull("Board found", g.getBoard());
        assertEquals("List of moves has two", 2, g.getMoves().size());

        assertEquals("Last move is last touch of the file", middle, g.getId().getModified());
    }

}
